function resInflamM1()
% resInflamM1 resproduces figures 5 & 6 from
% Dunster et al (2014) Resolution of inflammation: a mathematical model of neutrophil and macrophage interactions. Bulletin of mathematical biology, 76(8), pp.1953-1980.
% 
% 2017-01-13
% Joanne L Dunster @CardioMaths
% 
% Please cite the above mentioned paper if you use this code 

clear; close all; clc;
format short;
tic

%initial conditions
u10=0; u20=0; u30=0; u40=0; 
disp({'Initial conditions'});
disp({'n1',u10, 'n2', u20, 'm',u30,'c',u40});
u0=[u10 u20 u30 u40];

%Length of damage (select 1 (healthy) or 4 (unhealthy))
cyc=4;
dam=cyc*pi;

%Time to solve odes
estart=0.1; etime=10000;
disp({'Solved to :', etime, 'mins'});
tspan = [estart etime];

%nondimensional parameter values (Tab 4), used for Fig 5 & 6
alpha=0.05; 
nnu=0.1; 
nbetaa=0.1; 
ngm=0.01; 
nphi=0.001; 
nga=1; 

% Fig 6 requires param phi adjusting
%nphi=0.09; %Damped osc
%nphi=0.2;
%nphi=0.55; %Value in Fig 6 looks like it is wrong (it should be something more like this)

options=odeset('RelTol',1e-8,'AbsTol',1e-10);

[t,u] = ode45(@eqsolv,tspan,u0,options);


%plotting figures
%----------------

figure;  
semilogx(t,u(:,1),'-','LineWidth',2');
hold on;
semilogx(t,u(:,2),'--','LineWidth',2');
semilogx(t,u(:,3),'-.','LineWidth',2');
xlim([estart,etime]);
if cyc==1
   ylim([0,0.08]); %healthy
else
   ylim([0,110]); %unhealthy
end

figure;
semilogx(t,u(:,4),'-','LineWidth',2');
hold on;
semilogx(t,u(:,5),'--','LineWidth',2');
xlim([estart,etime]);
if cyc==1
   ylim([0,0.025]); %healthy
else
   ylim([0,1.1]); %unhealthy
end

%--------------------------------------------------------------------------
%Full governing equations
    function du=eqsolv(t,u)
 
        du=zeros(4,1);
        f=fc(t);
         
         du(1)= u(4) - nnu*u(1); 
         du(2)= nnu*u(1) - nga*u(2) - nphi*u(3)*u(2); 
         du(3)= u(4) - ngm*u(3);
         du(4)= alpha*f + nga*u(2)^2/(nbetaa^2 + u(2)^2) - u(4);         
          
    end


%-----------------------------------------------------------------------
%Damage
     function y=fc(fct)
 
         y=sin(fct).^2;
         y=y.*(fct<dam);
        
     end

end

